uniform mat4 mat_modelView;
uniform mat4 mat_projection;

uniform vec2 _texCoordScale;
uniform vec2 _texCoordOffset;

attribute vec2 _vertex;

attribute vec4 _color;
varying vec4 _destinationColor; 

attribute vec2 _texCoordIn;
varying vec2 _texCoordOut;

void main()
{
	_destinationColor = _color / 255.0;
	_texCoordOut = (_texCoordIn * _texCoordScale) + _texCoordOffset;

	gl_Position = mat_projection * mat_modelView * vec4(_vertex, 0.0, 1.0);
}
 
// Uniforms are values which do not change during a rendering, for example the light position
// or the light color. Uniforms are available in vertex and fragment shaders. Uniforms are read-only.

// Attributes are only available in vertex shader and they are input values which change every vertex,
// for example the vertex position or normals. Attributes are read-only.

// Varyings are used for passing data from a vertex shader to a fragment shader. Varyings are (perspective correct)
// interpolated across the primitive. Varyings are read-only in fragment shader but are read- and writeable in vertex shader
// (but be careful, reading a varying type before writing to it will return an undefined value). If you want to use varyings
// you have to declare the same varying in your vertex shader and in your fragment shader.

// All uniform, attribute and varying types HAVE to be global. You are not allowed to specify a uniform/attribute/varying type in a function or a void.